//
//****************************************************************************
//
// Name: cdbs_sql_gen
//
// Purpose: This program reads a CDBS load file(s) and creates an SQL file
//          which will be used to load the CDBS database tables during the
//          delivery process.
//
// Arguments: file specification for load file - can be list or wildcard spec
//
// Inputs: Load file(s)
//
// Output: A single SQL file for loading the CDBS database
//
// History:
// 06/12/02  45993  mss   add THERMAL,THERMTAB cases
// 
//***************************************************************************
// 
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "loadfile.h"
#include "loadutils.h"
#include "cdbs_sql_gen.h"

int main(int argc, char **argv)
{
  if (argc < 2){
    printf("Must supply load file name as argument\n");
    exit(1);
  }

  // get the database name to use in the SQL
  char *cdbs_db;
  if ((cdbs_db = getenv("CDBS_DB")) == NULL){
    printf("CDBS_DB must be set to the CDBS database name\n");
    return (1);
  }

  // Get new delivery number to use in the SQL file name
  int delivery;
  if ((delivery = get_delivery_num()) == ERROR){
    printf ("Error getting next delivery number");
    exit(1);
  } 

  // Open the output SQL script and write initial SQL
  //
  char sql_filename[256];
  sprintf(sql_filename, "cdbs_delivery%-1d.sql", delivery);
  FILE *sql_file = fopen(sql_filename, "w");
  if (NULL==sql_file) {
    printf ("FAILED to open %s for writing SQL\n",sql_filename);
    exit(1);
  }

  fprintf(sql_file, "USE %s\n", cdbs_db);
  fprintf(sql_file, "go\n");

  // loop through all load files specified by the command-line argument
  table *load_table;
  int i;
  for (i=1; i<argc; i++){

    // Read load file into an internal table
    //
    printf("Processing %s ...\n",argv[i]); 
    if ((load_table = read_loadfile(argv[i])) == NULL){
      fclose(sql_file);
      remove(sql_filename);
      printf("Error reading the load file: %s into internal table\n",
	     argv[i]);
      printf("No SQL file produced\n");
      exit(1);
    }
    
    // Check if this is an expanded or unexpanded load file and
    // process accordingly
    //
    if (get_tab_cell(load_table, "EXPANSION_NUMBER", 0) == NULL){
      // UNEXPANDED case
      if (ERROR == load_unexpanded(load_table, sql_file, delivery)){
	free_table(load_table);
	fclose(sql_file);
	remove(sql_filename);
	printf("Error processing the file: %s\n", argv[i]);
	printf("No SQL file produced\n");
	exit(1);
      }
    }
    else {
      // EXPANDED CASE
      if (ERROR == load_expanded(load_table, sql_file, delivery)){
	free_table(load_table);
	fclose(sql_file);
	remove(sql_filename);
	printf("Error processing the file: %s\n", argv[i]);
	printf("No SQL file produced\n");
	exit(1);
      }
    }
    free_table(load_table);
  }

  // Finish up
  //
  fclose(sql_file);
  printf("\nProcessing complete -- %s generated\n", sql_filename);
    
  exit(0);  
}
